@@ -57,6 +57,30 @@ class DvrEdgeHaRouter(dvr_edge_router.DvrEdgeRouter,
             self._get_snat_int_device_name,
             constants.SNAT_INT_DEV_PREFIX)
 
+    def add_centralized_floatingip(self, fip, fip_cidr):
+        interface_name = self.get_snat_external_device_interface_name(
+                self.get_ex_gw_port())
+        self._add_vip(fip_cidr, interface_name)
+
+        self.ha_port = self.router.get(constants.HA_INTERFACE_KEY)
+        if (self.is_router_master() and self.ha_port and
+                self.ha_port['status'] == constants.PORT_STATUS_ACTIVE):
+            return super(DvrEdgeHaRouter, self).add_centralized_floatingip(
+                fip, fip_cidr)
+        else:
+            return constants.FLOATINGIP_STATUS_ACTIVE
+
+    def remove_centralized_floatingip(self, fip_cidr):
+        self._remove_vip(fip_cidr)
+        if self.is_router_master():
+            super(DvrEdgeHaRouter, self).remove_centralized_floatingip(
+                fip_cidr)
+
+    def _get_centralized_fip_cidr_set(self):
+        interface_name = self.get_snat_external_device_interface_name(
+                self.get_ex_gw_port())
+        return set(self._get_cidrs_from_keepalived(interface_name))
+
     def external_gateway_added(self, ex_gw_port, interface_name):
         super(DvrEdgeHaRouter, self).external_gateway_added(
             ex_gw_port, interface_name)
