@@ -239,8 +239,7 @@ class DvrLocalRouter(dvr_router_base.DvrRouterBase):
                 arp_delete.add(arp_entry)
         self._pending_arp_set -= arp_delete
 
-    def _update_arp_entry(
-        self, ip, mac, subnet_id, operation, nud_state='permanent'):
+    def _update_arp_entry(self, ip, mac, subnet_id, operation):
         """Add or delete arp entry into router namespace for the subnet."""
         port = self._get_internal_port(subnet_id)
         # update arp entry only if the subnet is attached to the router
@@ -253,7 +252,7 @@ class DvrLocalRouter(dvr_router_base.DvrRouterBase):
             device = ip_lib.IPDevice(interface_name, namespace=self.ns_name)
             if device.exists():
                 if operation == 'add':
-                    device.neigh.add(ip, mac, nud_state=nud_state)
+                    device.neigh.add(ip, mac)
                 elif operation == 'delete':
                     device.neigh.delete(ip, mac)
                 return True
@@ -277,14 +276,12 @@ class DvrLocalRouter(dvr_router_base.DvrRouterBase):
         subnet_ports = self.agent.get_ports_by_subnet(subnet_id)
 
         for p in subnet_ports:
-            nud_state = 'permanent' if p.get('device_owner') else 'reachable'
             if p['device_owner'] not in lib_constants.ROUTER_INTERFACE_OWNERS:
                 for fixed_ip in p['fixed_ips']:
                     self._update_arp_entry(fixed_ip['ip_address'],
                                            p['mac_address'],
                                            subnet_id,
-                                           'add',
-                                           nud_state=nud_state)
+                                           'add')
         self._process_arp_cache_for_internal_port(subnet_id)
 
     @staticmethod
@@ -405,7 +402,12 @@ class DvrLocalRouter(dvr_router_base.DvrRouterBase):
             self._set_subnet_arp_info(subnet['id'])
             if ex_gw_port:
                 # Check for address_scopes here if gateway exists.
-                if self._check_if_address_scopes_match(port, ex_gw_port):
+                address_scopes_match = self._check_if_address_scopes_match(
+                    port, ex_gw_port)
+                if (address_scopes_match and
+                    (self.agent_conf.agent_mode in
+                        [lib_constants.L3_AGENT_MODE_DVR,
+                         lib_constants.L3_AGENT_MODE_DVR_SNAT])):
                     self._add_interface_routing_rule_to_router_ns(port)
                     self._add_interface_route_to_fip_ns(port)
         self._snat_redirect_add_from_port(port)
@@ -414,9 +416,12 @@ class DvrLocalRouter(dvr_router_base.DvrRouterBase):
         ex_gw_port = self.get_ex_gw_port()
         if not ex_gw_port:
             return
-        if self._check_if_address_scopes_match(port, ex_gw_port):
-            # If address scopes match there is no need to cleanup the
-            # snat redirect rules, hence return here.
+        address_scopes_match = self._check_if_address_scopes_match(
+            port, ex_gw_port)
+        if (address_scopes_match and
+            (self.agent_conf.agent_mode in
+                [lib_constants.L3_AGENT_MODE_DVR,
+                 lib_constants.L3_AGENT_MODE_DVR_SNAT])):
             return
         sn_port = self.get_snat_port_for_internal_port(port)
         if not sn_port:
@@ -435,7 +440,12 @@ class DvrLocalRouter(dvr_router_base.DvrRouterBase):
 
         # Delete DVR address_scope static route for the removed interface
         # Check for address_scopes here.
-        if self._check_if_address_scopes_match(port, self.ex_gw_port):
+        address_scopes_match = self._check_if_address_scopes_match(
+            port, self.ex_gw_port)
+        if (address_scopes_match and
+            (self.agent_conf.agent_mode in
+                [lib_constants.L3_AGENT_MODE_DVR,
+                 lib_constants.L3_AGENT_MODE_DVR_SNAT])):
             self._delete_interface_route_in_fip_ns(port)
             self._delete_interface_routing_rule_in_router_ns(port)
             # If address scopes match there is no need to cleanup the
@@ -469,20 +479,28 @@ class DvrLocalRouter(dvr_router_base.DvrRouterBase):
 
     def enable_snat_redirect_rules(self, ex_gw_port):
         for p in self.internal_ports:
-            if not self._check_if_address_scopes_match(p, ex_gw_port):
-                gateway = self.get_snat_port_for_internal_port(p)
-                if not gateway:
-                    continue
+            gateway = self.get_snat_port_for_internal_port(p)
+            if not gateway:
+                continue
+            address_scopes_match = self._check_if_address_scopes_match(
+                p, ex_gw_port)
+            if (not address_scopes_match or
+                (self.agent_conf.agent_mode ==
+                    n_const.L3_AGENT_MODE_DVR_NO_EXTERNAL)):
                 internal_dev = self.get_internal_device_name(p['id'])
                 self._snat_redirect_add(gateway, p, internal_dev)
 
     def disable_snat_redirect_rules(self, ex_gw_port):
         for p in self.internal_ports:
-            if not self._check_if_address_scopes_match(p, ex_gw_port):
-                gateway = self.get_snat_port_for_internal_port(
-                    p, self.snat_ports)
-                if not gateway:
-                    continue
+            gateway = self.get_snat_port_for_internal_port(
+                p, self.snat_ports)
+            if not gateway:
+                continue
+            address_scopes_match = self._check_if_address_scopes_match(
+                p, ex_gw_port)
+            if (not address_scopes_match or
+                (self.agent_conf.agent_mode ==
+                    n_const.L3_AGENT_MODE_DVR_NO_EXTERNAL)):
                 internal_dev = self.get_internal_device_name(p['id'])
                 self._snat_redirect_remove(gateway, p, internal_dev)
 
@@ -577,7 +595,17 @@ class DvrLocalRouter(dvr_router_base.DvrRouterBase):
                 self.connect_rtr_2_fip()
         super(DvrLocalRouter, self).process_external()
 
+    def _check_rtr_2_fip_connect(self):
+        """Checks if the rtr to fip connect exists, if not sets to false."""
+        fip_ns_name = self.fip_ns.get_name()
+        ip_wrapper = ip_lib.IPWrapper(namespace=fip_ns_name)
+        if ip_wrapper.netns.exists(fip_ns_name):
+            fip_2_rtr_name = self.fip_ns.get_int_device_name(self.router_id)
+            if not ip_lib.device_exists(fip_2_rtr_name, namespace=fip_ns_name):
+                self.rtr_fip_connect = False
+
     def connect_rtr_2_fip(self):
+        self._check_rtr_2_fip_connect()
         if self.fip_ns.agent_gateway_port and not self.rtr_fip_connect:
             ex_gw_port = self.get_ex_gw_port()
             self.fip_ns.create_rtr_2_fip_link(self)
