@@ -13,19 +13,20 @@
 #    under the License.
 #
 
+from neutron_lib.api.definitions import port as port_def
 from neutron_lib.api import validators
 
-from neutron.api.v2 import attributes as attr
-from neutron.db import _utils as db_utils
-from neutron.db import db_base_plugin_v2
-
 from neutron.common import utils
+from neutron.db import _resource_extend as resource_extend
+from neutron.db import _utils as db_utils
+from neutron.db import api as db_api
 from neutron.extensions import allowedaddresspairs as addr_pair
 from neutron.objects import exceptions
 from neutron.objects.port.extensions import (allowedaddresspairs
     as obj_addr_pair)
 
 
+@resource_extend.has_resource_extenders
 class AllowedAddressPairsMixin(object):
     """Mixin class for allowed address pairs."""
 
@@ -34,7 +35,7 @@ class AllowedAddressPairsMixin(object):
         if not validators.is_attr_set(allowed_address_pairs):
             return []
         try:
-            with context.session.begin(subtransactions=True):
+            with db_api.context_manager.writer.using(context):
                 for address_pair in allowed_address_pairs:
                     # use port.mac_address if no mac address in address pair
                     if 'mac_address' not in address_pair:
@@ -63,20 +64,19 @@ class AllowedAddressPairsMixin(object):
         return [self._make_allowed_address_pairs_dict(pair.db_obj)
                 for pair in pairs]
 
-    def _extend_port_dict_allowed_address_pairs(self, port_res, port_db):
+    @staticmethod
+    @resource_extend.extends([port_def.COLLECTION_NAME])
+    def _extend_port_dict_allowed_address_pairs(port_res, port_db):
         # If port_db is provided, allowed address pairs will be accessed via
         # sqlalchemy models. As they're loaded together with ports this
         # will not cause an extra query.
         allowed_address_pairs = [
-            self._make_allowed_address_pairs_dict(address_pair) for
+            AllowedAddressPairsMixin._make_allowed_address_pairs_dict(
+                address_pair) for
             address_pair in port_db.allowed_address_pairs]
         port_res[addr_pair.ADDRESS_PAIRS] = allowed_address_pairs
         return port_res
 
-    # Register dict extend functions for ports
-    db_base_plugin_v2.NeutronDbPluginV2.register_dict_extend_funcs(
-        attr.PORTS, ['_extend_port_dict_allowed_address_pairs'])
-
     def _delete_allowed_address_pairs(self, context, id):
         obj_addr_pair.AllowedAddressPair.delete_objects(
             context, port_id=id)
