@@ -133,8 +133,6 @@ class DVRResourceOperationHandler(object):
                 context, router_db,
                 old_owner=old_owner,
                 new_owner=const.DEVICE_OWNER_DVR_INTERFACE)
-            self.l3plugin.set_extra_attr_value(context, router_db,
-                                               'distributed', True)
         else:
             if router.get('ha'):
                 new_owner = const.DEVICE_OWNER_HA_REPLICATED_INT
@@ -144,13 +142,13 @@ class DVRResourceOperationHandler(object):
                 context, router_db,
                 old_owner=const.DEVICE_OWNER_DVR_INTERFACE,
                 new_owner=new_owner)
-            self.l3plugin.set_extra_attr_value(context, router_db,
-                                               'distributed', False)
 
         cur_agents = self.l3plugin.list_l3_agents_hosting_router(
             context, router_db['id'])['agents']
         for agent in cur_agents:
             self.l3plugin._unbind_router(context, router_db['id'], agent['id'])
+        self.l3plugin.set_extra_attr_value(
+            context, router_db, 'distributed', migrating_to_distributed)
 
     @registry.receives(resources.ROUTER, [events.AFTER_UPDATE])
     def _delete_snat_interfaces_after_change(self, resource, event, trigger,
@@ -200,11 +198,11 @@ class DVRResourceOperationHandler(object):
         return ports
 
     def _add_csnat_router_interface_port(
-            self, context, router, network_id, subnet_id, do_pop=True):
+            self, context, router, network_id, subnets, do_pop=True):
         """Add SNAT interface to the specified router and subnet."""
         port_data = {'tenant_id': '',
                      'network_id': network_id,
-                     'fixed_ips': [{'subnet_id': subnet_id}],
+                     'fixed_ips': subnets,
                      'device_id': router.id,
                      'device_owner': const.DEVICE_OWNER_ROUTER_SNAT,
                      'admin_state_up': True,
@@ -251,15 +249,31 @@ class DVRResourceOperationHandler(object):
         )
         LOG.info('SNAT interface port list does not exist,'
                  ' so create one: %s', port_list)
+        v6_subnets = []
+        network = None
         for intf in int_ports:
             if intf.fixed_ips:
                 # Passing the subnet for the port to make sure the IP's
                 # are assigned on the right subnet if multiple subnet
                 # exists
-                snat_port = self._add_csnat_router_interface_port(
-                    context, router, intf['network_id'],
-                    intf['fixed_ips'][0]['subnet_id'], do_pop=False)
-                port_list.append(snat_port)
+                for fixed_ip in intf['fixed_ips']:
+                    ip_version = n_utils.get_ip_version(
+                        fixed_ip.get('ip_address'))
+                    if ip_version == const.IP_VERSION_4:
+                        snat_port = self._add_csnat_router_interface_port(
+                            context, router, intf['network_id'],
+                            [{'subnet_id': fixed_ip['subnet_id']}],
+                            do_pop=False)
+                        port_list.append(snat_port)
+                    else:
+                        v6_subnets.append(
+                            {"subnet_id": fixed_ip['subnet_id']})
+                        network = intf['network_id']
+        if v6_subnets:
+            snat_port = self._add_csnat_router_interface_port(
+                context, router, network,
+                v6_subnets, do_pop=False)
+            port_list.append(snat_port)
         if port_list:
             self.l3plugin._populate_mtu_and_subnets_for_ports(
                 context, port_list)
@@ -396,7 +410,7 @@ class DVRResourceOperationHandler(object):
         admin_context = context.elevated()
         self._add_csnat_router_interface_port(
             admin_context, router_db, port['network_id'],
-            port['fixed_ips'][-1]['subnet_id'])
+            [{'subnet_id': port['fixed_ips'][-1]['subnet_id']}])
 
     @registry.receives(resources.ROUTER_INTERFACE, [events.AFTER_CREATE])
     @db_api.retry_if_session_inactive()
@@ -593,29 +607,31 @@ class _DVRAgentInterfaceMixin(object):
         LOG.debug("Return the SNAT ports: %s", interfaces)
         return interfaces
 
+    def _get_gateway_port_host(self, context, router, gw_ports):
+        binding_objs = rb_obj.RouterL3AgentBinding.get_objects(
+            context, router_id=[router['id']])
+        if not binding_objs:
+            return
+
+        gw_port_id = router['gw_port_id']
+        # Collect gw ports only if available
+        if gw_port_id and gw_ports.get(gw_port_id):
+            l3_agent = ag_obj.Agent.get_object(context,
+                id=binding_objs[0].l3_agent_id)
+            return l3_agent.host
+
     def _build_routers_list(self, context, routers, gw_ports):
         # Perform a single query up front for all routers
         routers = super(_DVRAgentInterfaceMixin, self)._build_routers_list(
             context, routers, gw_ports)
         if not routers:
             return []
-        router_ids = [r['id'] for r in routers]
-        binding_objs = rb_obj.RouterL3AgentBinding.get_objects(
-            context, router_id=router_ids)
-        bindings = dict((b.router_id, b) for b in binding_objs)
-        for rtr in routers:
-            gw_port_id = rtr['gw_port_id']
-            # Collect gw ports only if available
-            if gw_port_id and gw_ports.get(gw_port_id):
-                binding = bindings.get(rtr['id'])
-                if not binding:
-                    rtr['gw_port_host'] = None
-                    LOG.debug('No snat is bound to router %s', rtr['id'])
-                    continue
-
-                l3_agent = ag_obj.Agent.get_object(context,
-                        id=binding.l3_agent_id)
-                rtr['gw_port_host'] = l3_agent.host
+        for router in routers:
+            gw_port_host = self._get_gateway_port_host(
+                context, router, gw_ports)
+            LOG.debug("Set router %s gateway port host: %s",
+                      router['id'], gw_port_host)
+            router['gw_port_host'] = gw_port_host
 
         return routers
 
@@ -902,7 +918,7 @@ class _DVRAgentInterfaceMixin(object):
                 return f_port
 
     def _generate_arp_table_and_notify_agent(
-        self, context, fixed_ip, mac_address, notifier, nud_state='permanent'):
+        self, context, fixed_ip, mac_address, notifier):
         """Generates the arp table entry and notifies the l3 agent."""
         ip_address = fixed_ip['ip_address']
         subnet = fixed_ip['subnet_id']
@@ -914,8 +930,7 @@ class _DVRAgentInterfaceMixin(object):
             return
         arp_table = {'ip_address': ip_address,
                      'mac_address': mac_address,
-                     'subnet_id': subnet,
-                     'nud_state': nud_state}
+                     'subnet_id': subnet}
         notifier(context, router_id, arp_table)
 
     def _get_subnet_id_for_given_fixed_ip(
@@ -959,14 +974,11 @@ class _DVRAgentInterfaceMixin(object):
             return
         allowed_address_pair_fixed_ips = (
             self._get_allowed_address_pair_fixed_ips(context, port_dict))
-        for fixed_ip in fixed_ips:
+        changed_fixed_ips = fixed_ips + allowed_address_pair_fixed_ips
+        for fixed_ip in changed_fixed_ips:
             self._generate_arp_table_and_notify_agent(
                 context, fixed_ip, port_dict['mac_address'],
                 self.l3_rpc_notifier.add_arp_entry)
-        for fixed_ip in allowed_address_pair_fixed_ips:
-            self._generate_arp_table_and_notify_agent(
-                context, fixed_ip, port_dict['mac_address'],
-                self.l3_rpc_notifier.add_arp_entry, nud_state='reachable')
 
     def delete_arp_entry_for_dvr_service_port(
         self, context, port_dict, fixed_ips_to_delete=None):
