@@ -14,14 +14,16 @@
 
 import abc
 
+from neutron_lib.api import extensions as api_extensions
+from neutron_lib.api import validators
+from neutron_lib import exceptions
+from neutron_lib.plugins import directory
 from oslo_serialization import jsonutils
+import six
 
 from neutron._i18n import _
 from neutron.api import extensions
-from neutron.api.v2 import attributes as attr
 from neutron.api.v2 import base
-from neutron.common import exceptions
-from neutron import manager
 
 
 AZ_HINTS_DB_LEN = 255
@@ -38,7 +40,7 @@ def convert_az_string_to_list(az_string):
 
 def _validate_availability_zone_hints(data, valid_value=None):
     # syntax check only here. existence of az will be checked later.
-    msg = attr.validate_list_of_unique_strings(data)
+    msg = validators.validate_list_of_unique_strings(data)
     if msg:
         return msg
     az_string = convert_az_list_to_string(data)
@@ -46,9 +48,8 @@ def _validate_availability_zone_hints(data, valid_value=None):
         msg = _("Too many availability_zone_hints specified")
         raise exceptions.InvalidInput(error_message=msg)
 
-
-attr.validators['type:availability_zone_hints'] = (
-    _validate_availability_zone_hints)
+validators.add_validator('availability_zone_hints',
+                         _validate_availability_zone_hints)
 
 # Attribute Map
 RESOURCE_NAME = 'availability_zone'
@@ -78,7 +79,7 @@ class AvailabilityZoneNotFound(exceptions.NotFound):
     message = _("AvailabilityZone %(availability_zone)s could not be found.")
 
 
-class Availability_zone(extensions.ExtensionDescriptor):
+class Availability_zone(api_extensions.ExtensionDescriptor):
     """Availability zone extension."""
 
     @classmethod
@@ -103,9 +104,7 @@ class Availability_zone(extensions.ExtensionDescriptor):
     @classmethod
     def get_resources(cls):
         """Returns Ext Resources."""
-        my_plurals = [(key, key[:-1]) for key in RESOURCE_ATTRIBUTE_MAP.keys()]
-        attr.PLURALS.update(dict(my_plurals))
-        plugin = manager.NeutronManager.get_plugin()
+        plugin = directory.get_plugin()
         params = RESOURCE_ATTRIBUTE_MAP.get(AVAILABILITY_ZONES)
         controller = base.create_resource(AVAILABILITY_ZONES,
                                           RESOURCE_NAME, plugin, params)
@@ -122,6 +121,7 @@ class Availability_zone(extensions.ExtensionDescriptor):
             return {}
 
 
+@six.add_metaclass(abc.ABCMeta)
 class AvailabilityZonePluginBase(object):
     """REST API to operate the Availability Zone."""
 
