@@ -16,6 +16,7 @@
 import abc
 
 import netaddr
+from neutron_lib.api import converters
 from neutron_lib.api import extensions as api_extensions
 from neutron_lib.api import validators
 from neutron_lib import constants as const
@@ -23,7 +24,6 @@ from neutron_lib.db import constants as db_const
 from neutron_lib import exceptions as nexception
 from neutron_lib.plugins import directory
 from oslo_utils import netutils
-from oslo_utils import uuidutils
 import six
 
 from neutron._i18n import _
@@ -40,6 +40,11 @@ class SecurityGroupInvalidPortRange(nexception.InvalidInput):
                 "<= port_range_max")
 
 
+class SecurityGroupInvalidProtocolForPortRange(nexception.InvalidInput):
+    message = _("Invalid protocol %(protocol)s for port range, only "
+                "supported for TCP and UDP.")
+
+
 class SecurityGroupInvalidPortValue(nexception.InvalidInput):
     message = _("Invalid value for port %(port)s")
 
@@ -184,16 +189,6 @@ def convert_validate_port_value(port):
         raise SecurityGroupInvalidPortValue(port=port)
 
 
-def convert_to_uuid_list_or_none(value_list):
-    if value_list is None:
-        return
-    for sg_id in value_list:
-        if not uuidutils.is_uuid_like(sg_id):
-            msg = _("'%s' is not an integer or uuid") % sg_id
-            raise nexception.InvalidInput(error_message=msg)
-    return value_list
-
-
 def convert_ip_prefix_to_cidr(ip_prefix):
     if not ip_prefix:
         return
@@ -204,7 +199,10 @@ def convert_ip_prefix_to_cidr(ip_prefix):
         raise exceptions.InvalidCIDR(input=ip_prefix)
 
 
-def _validate_name_not_default(data, valid_values=None):
+def _validate_name_not_default(data, max_len=db_const.NAME_FIELD_SIZE):
+    msg = validators.validate_string(data, max_len)
+    if msg:
+        return msg
     if data.lower() == "default":
         raise SecurityGroupDefaultAlreadyExists()
 
@@ -279,7 +277,9 @@ EXTENDED_ATTRIBUTES_2_0 = {
     'ports': {SECURITYGROUPS: {'allow_post': True,
                                'allow_put': True,
                                'is_visible': True,
-                               'convert_to': convert_to_uuid_list_or_none,
+                               'convert_to':
+                                   converters.convert_none_to_empty_list,
+                               'validate': {'type:uuid_list': None},
                                'default': const.ATTR_NOT_SPECIFIED}}}
 
 # Register the configuration options
