@@ -180,7 +180,7 @@ class IpProtocolEnum(obj_fields.Enum):
             valid_values=list(
                 itertools.chain(
                     lib_constants.IP_PROTOCOL_MAP.keys(),
-                    [str(v) for v in lib_constants.IP_PROTOCOL_MAP.values()]
+                    [str(v) for v in range(256)]
                 )
             ),
             **kwargs)
@@ -260,6 +260,10 @@ class DictOfMiscValuesField(obj_fields.AutoTypedField):
     AUTO_TYPE = DictOfMiscValues
 
 
+class ListOfDictOfMiscValuesField(obj_fields.AutoTypedField):
+    AUTO_TYPE = obj_fields.List(DictOfMiscValuesField())
+
+
 class IPNetwork(obj_fields.FieldType):
     """IPNetwork custom field.
 
@@ -298,3 +302,7 @@ class UUID(obj_fields.UUID):
 
 class UUIDField(obj_fields.AutoTypedField):
     AUTO_TYPE = UUID()
+
+
+class FloatingIPStatusEnumField(obj_fields.AutoTypedField):
+    AUTO_TYPE = obj_fields.Enum(valid_values=constants.VALID_FLOATINGIP_STATUS)
