@@ -53,6 +53,14 @@ class L2populationMechanismDriver(api.MechanismDriver):
                                    ip_address=ip['ip_address'])
                 for ip in port['fixed_ips']]
 
+    def _remove_flooding(self, fdb_entries):
+        for network_fdb in fdb_entries.values():
+            for agent_fdb in network_fdb.get('ports', {}).values():
+                try:
+                    agent_fdb.remove(const.FLOODING_ENTRY)
+                except ValueError:
+                    pass
+
     def check_vlan_transparency(self, context):
         """L2population driver vlan transparency support."""
         return True
@@ -240,6 +248,14 @@ class L2populationMechanismDriver(api.MechanismDriver):
 
         return agents
 
+    def agent_restarted(self, context):
+        agent_host = context.host
+        session = db_api.get_reader_session()
+        agent = l2pop_db.get_agent_by_host(session, agent_host)
+        if l2pop_db.get_agent_uptime(agent) < cfg.CONF.l2pop.agent_boot_time:
+            return True
+        return False
+
     def update_port_down(self, context):
         port = context.current
         agent_host = context.host
@@ -249,11 +265,15 @@ class L2populationMechanismDriver(api.MechanismDriver):
             l3plugin, "list_router_ids_on_host", None):
             admin_context = n_context.get_admin_context()
             port_context = context._plugin_context
-            if l3plugin.list_router_ids_on_host(
-                admin_context, agent_host, [port['device_id']]):
-                return
             fdb_entries = self._get_agent_fdb(
-                port_context, context.bottom_bound_segment, port, agent_host)
+                port_context, context.bottom_bound_segment, port, agent_host,
+                include_ha_router_ports=True)
+            if (fdb_entries and
+                l3plugin.list_router_ids_on_host(
+                    admin_context, agent_host, [port['device_id']])):
+                # NOTE(slaweq): in case this is HA router, remove unicast
+                # entries to this port but don't remove flood entry
+                self._remove_flooding(fdb_entries)
             self.L2populationAgentNotify.remove_fdb_entries(
                 self.rpc_ctx, fdb_entries)
 
@@ -281,8 +301,10 @@ class L2populationMechanismDriver(api.MechanismDriver):
             segment, agent_ip, network_id)
         other_fdb_ports = other_fdb_entries[network_id]['ports']
 
-        if agent_active_ports == 1 or (l2pop_db.get_agent_uptime(agent) <
-                                       cfg.CONF.l2pop.agent_boot_time):
+        # with high concurrency more than 1 port may be activated on an agent
+        # at the same time (like VM port + a DVR port) so checking for 1 or 2
+        is_first_port = agent_active_ports in (1, 2)
+        if is_first_port or self.agent_restarted(context):
             # First port activated on current agent in this network,
             # we have to provide it with the whole list of fdb entries
             agent_fdb_entries = self._create_agent_fdb(session,
@@ -306,7 +328,8 @@ class L2populationMechanismDriver(api.MechanismDriver):
         self.L2populationAgentNotify.add_fdb_entries(self.rpc_ctx,
                                                      other_fdb_entries)
 
-    def _get_agent_fdb(self, context, segment, port, agent_host):
+    def _get_agent_fdb(self, context, segment, port, agent_host,
+                       include_ha_router_ports=False):
         if not agent_host:
             return
 
@@ -335,9 +358,10 @@ class L2populationMechanismDriver(api.MechanismDriver):
                 const.FLOODING_ENTRY)
         # Notify other agents to remove fdb rules for current port
         if (port['device_owner'] != const.DEVICE_OWNER_DVR_INTERFACE and
+           (include_ha_router_ports or
             not l3_hamode_db.is_ha_router_port(context,
                                                port['device_owner'],
-                                               port['device_id'])):
+                                               port['device_id']))):
             fdb_entries = self._get_port_fdb_entries(port)
             other_fdb_entries[network_id]['ports'][agent_ip] += fdb_entries
 
