@@ -13,14 +13,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from neutron_lib.api.definitions import port_security as psec
+from neutron_lib.api import validators
+from neutron_lib.utils import net
 from oslo_log import log as logging
 
-from neutron._i18n import _LI
-from neutron.api.v2 import attributes as attrs
-from neutron.common import utils
 from neutron.db import common_db_mixin
 from neutron.db import portsecurity_db_common as ps_db_common
-from neutron.extensions import portsecurity as psec
 from neutron.plugins.ml2 import driver_api as api
 
 LOG = logging.getLogger(__name__)
@@ -32,7 +31,7 @@ class PortSecurityExtensionDriver(api.ExtensionDriver,
     _supported_extension_alias = 'port-security'
 
     def initialize(self):
-        LOG.info(_LI("PortSecurityExtensionDriver initialization complete"))
+        LOG.info("PortSecurityExtensionDriver initialization complete")
 
     @property
     def extension_alias(self):
@@ -72,10 +71,10 @@ class PortSecurityExtensionDriver(api.ExtensionDriver,
         otherwise the value associated with the network is returned.
         """
         # we don't apply security groups for dhcp, router
-        if port.get('device_owner') and utils.is_port_trusted(port):
+        if port.get('device_owner') and net.is_port_trusted(port):
             return False
 
-        if attrs.is_attr_set(port.get(psec.PORTSECURITY)):
+        if validators.is_attr_set(port.get(psec.PORTSECURITY)):
             port_security_enabled = port[psec.PORTSECURITY]
         else:
             port_security_enabled = self._get_network_security_binding(
