@@ -92,7 +92,8 @@ class QoSPlugin(qos.QoSPluginBase):
         if policy_id is None:
             return
 
-        policy = policy_object.QosPolicy.get_object(context, id=policy_id)
+        policy = policy_object.QosPolicy.get_object(
+            context.elevated(), id=policy_id)
         self.validate_policy_for_port(policy, port)
 
     def _validate_update_port_callback(self, resource, event, trigger,
@@ -107,7 +108,9 @@ class QoSPlugin(qos.QoSPluginBase):
 
         updated_port = ports_object.Port.get_object(
             context, id=kwargs['port']['id'])
-        policy = policy_object.QosPolicy.get_object(context, id=policy_id)
+
+        policy = policy_object.QosPolicy.get_object(
+            context.elevated(), id=policy_id)
 
         self.validate_policy_for_port(policy, updated_port)
 
@@ -123,7 +126,8 @@ class QoSPlugin(qos.QoSPluginBase):
         if policy_id is None or policy_id == original_policy_id:
             return
 
-        policy = policy_object.QosPolicy.get_object(context, id=policy_id)
+        policy = policy_object.QosPolicy.get_object(
+            context.elevated(), id=policy_id)
         ports = ports_object.Port.get_objects(
                 context, network_id=updated_network['id'])
         # Filter only this ports which don't have overwritten policy
@@ -313,6 +317,7 @@ class QoSPlugin(qos.QoSPluginBase):
             policy = self._get_policy_obj(context, policy_id)
             checker.check_bandwidth_rule_conflict(policy, rule_data)
             rule = rule_cls(context, qos_policy_id=policy_id, **rule_data)
+            checker.check_rules_conflict(policy, rule)
             rule.create()
             policy.obj_load_attr('rules')
             self.validate_policy(context, policy)
@@ -352,6 +357,7 @@ class QoSPlugin(qos.QoSPluginBase):
             policy.get_rule_by_id(rule_id)
             rule = rule_cls(context, id=rule_id)
             rule.update_fields(rule_data, reset_changes=True)
+            checker.check_rules_conflict(policy, rule)
             rule.update()
             policy.obj_load_attr('rules')
             self.validate_policy(context, policy)
