@@ -32,7 +32,6 @@ from oslo_config import cfg
 from oslo_utils import uuidutils
 import six
 
-from neutron.agent.common import config
 from neutron.agent.common import ovs_lib
 from neutron.agent.linux import bridge_lib
 from neutron.agent.linux import interface
@@ -40,6 +39,7 @@ from neutron.agent.linux import ip_lib
 from neutron.agent.linux import iptables_firewall
 from neutron.agent.linux import utils
 from neutron.common import utils as common_utils
+from neutron.conf.agent import common as config
 from neutron.db import db_base_plugin_common
 from neutron.plugins.ml2.drivers.linuxbridge.agent import \
     linuxbridge_neutron_agent as linuxbridge_agent
@@ -268,6 +268,8 @@ class RootHelperProcess(subprocess.Popen):
     def __init__(self, cmd, *args, **kwargs):
         for arg in ('stdin', 'stdout', 'stderr'):
             kwargs.setdefault(arg, subprocess.PIPE)
+        kwargs.setdefault('universal_newlines', True)
+
         self.namespace = kwargs.pop('namespace', None)
         self.cmd = cmd
         if self.namespace is not None:
@@ -376,7 +378,7 @@ class Pinger(object):
     def start(self):
         if self.proc and self.proc.is_running:
             raise RuntimeError("This pinger has already a running process")
-        ip_version = ip_lib.get_ip_version(self.address)
+        ip_version = common_utils.get_ip_version(self.address)
         ping_exec = 'ping' if ip_version == 4 else 'ping6'
         cmd = [ping_exec, self.address, '-W', str(self.timeout)]
         if self.count:
@@ -735,6 +737,7 @@ class OVSPortFixture(PortFixture):
                  hybrid_plug=False):
         super(OVSPortFixture, self).__init__(bridge, namespace, mac, port_id)
         self.hybrid_plug = hybrid_plug
+        self.vlan_tag = None
 
     def _create_bridge_fixture(self):
         return OVSBridgeFixture()
@@ -769,6 +772,10 @@ class OVSPortFixture(PortFixture):
             self.mac,
             bridge=self.bridge.br_name,
             namespace=self.namespace)
+        # NOTE(mangelajo): for OVS implementations remove the DEAD VLAN tag
+        # on ports that we intend to use as fake vm interfaces, they
+        # need to be flat. This is related to lp#1767422
+        self.bridge.clear_db_attribute("Port", port_name, "tag")
         self.addCleanup(self.bridge.delete_port, port_name)
         self.port = ip_lib.IPDevice(port_name, self.namespace)
 
@@ -923,12 +930,12 @@ class VethBridge(object):
 
     def __init__(self, ports):
         self.ports = ports
-        self.unallocated_ports = set(self.ports)
+        self.unallocated_ports = list(self.ports)
 
     def allocate_port(self):
         try:
             return self.unallocated_ports.pop()
-        except KeyError:
+        except IndexError:
             tools.fail('All FakeBridge ports (%s) are already allocated.' %
                        len(self.ports))
 
