@@ -24,7 +24,10 @@ import six
 import testtools
 
 from neutron.agent.l3 import agent as neutron_l3_agent
+from neutron.agent.l3 import dvr_edge_ha_router as dvr_ha_router
+from neutron.agent.l3 import dvr_edge_router
 from neutron.agent.l3 import dvr_fip_ns
+from neutron.agent.l3 import dvr_local_router
 from neutron.agent.l3 import dvr_snat_ns
 from neutron.agent.l3 import namespaces
 from neutron.agent.linux import ip_lib
@@ -112,6 +115,64 @@ class TestDvrRouter(framework.L3AgentTestFramework):
         self.assertEqual(4, default_rules_list_count)
         self.assertEqual(2, interface_rules_list_count)
 
+    def test_dvr_update_gateway_port_no_fip_fg_port_recovers_itself_with_fpr(
+        self):
+        self.agent.conf.agent_mode = 'dvr'
+        # Create the router with external net
+        router_info = self.generate_dvr_router_info()
+        external_gw_port = router_info['gw_port']
+        ext_net_id = router_info['_floatingips'][0]['floating_network_id']
+        self.mock_plugin_api.get_external_network_id.return_value = ext_net_id
+        router = self.manage_router(self.agent, router_info)
+        fg_port = router.fip_ns.agent_gateway_port
+        fg_port_name = router.fip_ns.get_ext_device_name(fg_port['id'])
+        fg_device = ip_lib.IPDevice(fg_port_name,
+                                    namespace=router.fip_ns.name)
+        fip_2_rtr_name = router.fip_ns.get_int_device_name(router.router_id)
+        fpr_device = ip_lib.IPDevice(fip_2_rtr_name,
+                                     namespace=router.fip_ns.name)
+        # Now validate if the gateway is properly configured.
+        rtr_2_fip, fip_2_rtr = router.rtr_fip_subnet.get_pair()
+        tbl_index = router._get_snat_idx(fip_2_rtr)
+        tbl_filter = ['table', tbl_index]
+        self.assertIn('gateway', fg_device.route.get_gateway(
+            filters=tbl_filter))
+        self._validate_fips_for_external_network(
+            router, router.fip_ns.get_name())
+        # Now delete the fg- port that was created
+        ext_net_bridge = self.agent.conf.external_network_bridge
+        router.fip_ns.driver.unplug(fg_port_name,
+                                    bridge=ext_net_bridge,
+                                    namespace=router.fip_ns.name,
+                                    prefix=dvr_fip_ns.FIP_EXT_DEV_PREFIX)
+        # Now check if the fg- port is missing.
+        self.assertFalse(fg_device.exists())
+        fpr_device.link.set_down()
+        # Now change the gateway ip for the router and do an update.
+        router.ex_gw_port = copy.deepcopy(router.ex_gw_port)
+        new_fg_port = copy.deepcopy(fg_port)
+        for subnet in new_fg_port['subnets']:
+            subnet['gateway_ip'] = '19.4.4.2'
+        router.router[n_const.FLOATINGIP_AGENT_INTF_KEY] = [new_fg_port]
+        self.assertRaises(n_exc.FloatingIpSetupException,
+                          self.agent._process_updated_router,
+                          router.router)
+        self.agent._process_updated_router(router.router)
+        self.assertTrue(fg_device.exists())
+        self.assertTrue(fpr_device.exists())
+        updated_route = fg_device.route.list_routes(
+                ip_version=lib_constants.IP_VERSION_4,
+                table=tbl_index)
+        expected_route = [{'cidr': '0.0.0.0/0',
+                           'dev': fg_port_name,
+                           'table': tbl_index,
+                           u'via': u'19.4.4.2'}]
+        self.assertEqual(expected_route, updated_route)
+        self._validate_fips_for_external_network(
+            router, router.fip_ns.get_name())
+        self._delete_router(self.agent, router.router_id)
+        self._assert_fip_namespace_deleted(external_gw_port)
+
     def test_dvr_update_gateway_port_with_no_gw_port_in_namespace(self):
         self.agent.conf.agent_mode = 'dvr'
 
@@ -1276,6 +1337,40 @@ class TestDvrRouter(framework.L3AgentTestFramework):
         self._assert_no_ip_addresses_on_interface(namespace,
                                                   ex_gw_port_name)
 
+    @mock.patch.object(dvr_local_router.DvrLocalRouter, 'connect_rtr_2_fip')
+    @mock.patch.object(
+        dvr_ha_router.DvrEdgeHaRouter, '_get_centralized_fip_cidr_set')
+    def test_dvr_ha_router_with_centralized_fip_calls_keepalived_cidr(
+        self, connect_rtr_2_fip_mock, fip_cidr_centralized_mock):
+
+        self._setup_dvr_ha_agents()
+        self._setup_dvr_ha_bridges()
+
+        router1 = self._create_dvr_ha_router(
+            self.agent, enable_gw=True,
+            enable_centralized_fip=True,
+            snat_bound_fip=True)
+        self.assertTrue(fip_cidr_centralized_mock.called)
+        restarted_agent = neutron_l3_agent.L3NATAgentWithStateReport(
+            self.agent.host, self.agent.conf)
+        self.manage_router(restarted_agent, router1.router)
+        self.assertTrue(fip_cidr_centralized_mock.called)
+
+    @mock.patch.object(dvr_local_router.DvrLocalRouter, 'connect_rtr_2_fip')
+    @mock.patch.object(
+        dvr_edge_router.DvrEdgeRouter, '_get_centralized_fip_cidr_set')
+    def test_dvr_router_with_centralized_fip_calls_keepalived_cidr(
+        self, connect_rtr_2_fip_mock, fip_cidr_centralized_mock):
+
+        router_info = self.generate_dvr_router_info(
+            enable_gw=True, enable_centralized_fip=True, snat_bound_fip=True)
+        router1 = self.manage_router(self.agent, router_info)
+        self.assertTrue(fip_cidr_centralized_mock.called)
+        restarted_agent = neutron_l3_agent.L3NATAgentWithStateReport(
+            self.agent.host, self.agent.conf)
+        self.manage_router(restarted_agent, router1.router)
+        self.assertTrue(fip_cidr_centralized_mock.called)
+
     def _test_dvr_ha_router_failover_with_gw_and_fip(self, enable_gw,
                                                      enable_centralized_fip,
                                                      snat_bound_fip):
@@ -1355,10 +1450,12 @@ class TestDvrRouter(framework.L3AgentTestFramework):
         self.assertFalse(r2_chsfr.called)
 
     def _setup_dvr_router_static_routes(
-        self, router_namespace=True, check_fpr_int_rule_delete=False):
+        self, router_namespace=True,
+        check_fpr_int_rule_delete=False, enable_ha=False):
         """Test to validate the extra routes on dvr routers."""
         self.agent.conf.agent_mode = 'dvr_snat'
-        router_info = self.generate_dvr_router_info(enable_snat=True)
+        router_info = self.generate_dvr_router_info(
+            enable_snat=True, enable_ha=enable_ha)
         router1 = self.manage_router(self.agent, router_info)
         self.assertTrue(self._namespace_exists(router1.ns_name))
         self._assert_snat_namespace_exists(router1)
@@ -1377,7 +1474,9 @@ class TestDvrRouter(framework.L3AgentTestFramework):
         router_updated = self.agent.router_info[router_info['id']]
         if router_namespace:
             self._assert_extra_routes(router_updated)
-            self._assert_extra_routes(router_updated, namespace=snat_ns_name)
+            if not enable_ha:
+                self._assert_extra_routes(router_updated,
+                                          namespace=snat_ns_name)
         else:
             rtr_2_fip, fip_2_rtr = router_updated.rtr_fip_subnet.get_pair()
             # Now get the table index based on the fpr-interface ip.
@@ -1467,6 +1566,9 @@ class TestDvrRouter(framework.L3AgentTestFramework):
         self):
         self._setup_dvr_router_static_routes()
 
+    def test_dvr_ha_rtr_static_routes_in_rtr_namespace(self):
+        self._setup_dvr_router_static_routes(enable_ha=True)
+
     def test_dvr_router_rule_and_route_table_cleared_when_fip_removed(
         self):
         self._setup_dvr_router_static_routes(
@@ -1514,19 +1616,20 @@ class TestDvrRouter(framework.L3AgentTestFramework):
 
     def _assert_interface_rules_on_gateway_remove(
         self, router, agent, address_scopes, agent_gw_port,
-        rfp_device, fpr_device):
+        rfp_device, fpr_device, no_external=False):
 
         router.router[n_const.SNAT_ROUTER_INTF_KEY] = []
         router.router['gw_port'] = ""
         router.router['gw_port_host'] = ""
         self.agent._process_updated_router(router.router)
         router_updated = self.agent.router_info[router.router['id']]
-        self.assertFalse(rfp_device.exists())
-        self.assertFalse(fpr_device.exists())
         self.assertTrue(self._namespace_exists(router_updated.ns_name))
-        self._assert_fip_namespace_deleted(
-            agent_gw_port, assert_ovs_interface=False)
-        if not address_scopes:
+        if not no_external:
+            self.assertFalse(rfp_device.exists())
+            self.assertFalse(fpr_device.exists())
+            self._assert_fip_namespace_deleted(
+                agent_gw_port, assert_ovs_interface=False)
+        if not address_scopes or no_external:
             ns_ipr = ip_lib.IPRule(namespace=router_updated.ns_name)
             ip4_rules_list = ns_ipr.rule.list_rules(lib_constants.IP_VERSION_4)
             ip6_rules_list = ns_ipr.rule.list_rules(lib_constants.IP_VERSION_6)
@@ -1546,9 +1649,6 @@ class TestDvrRouter(framework.L3AgentTestFramework):
         self.agent.conf.agent_mode = 'dvr'
         router_info = self.generate_dvr_router_info(
             enable_snat=True, enable_gw=True, enable_floating_ip=True)
-        fip_agent_gw_port = router_info[n_const.FLOATINGIP_AGENT_INTF_KEY]
-        self.mock_plugin_api.get_agent_gateway_port.return_value = (
-            fip_agent_gw_port[0])
         router_info[lib_constants.FLOATINGIP_KEY] = []
         if address_scopes:
             address_scope1 = {
@@ -1566,6 +1666,12 @@ class TestDvrRouter(framework.L3AgentTestFramework):
             address_scope1)
         router_info[lib_constants.INTERFACE_KEY][1]['address_scopes'] = (
             address_scope2)
+        # should have the same address_scopes as gw_port
+        fip_agent_gw_ports = router_info[n_const.FLOATINGIP_AGENT_INTF_KEY]
+        fip_agent_gw_ports[0]['address_scopes'] = (
+            router_info['gw_port']['address_scopes'])
+        self.mock_plugin_api.get_agent_gateway_port.return_value = (
+            fip_agent_gw_ports[0])
         router1 = self.manage_router(self.agent, router_info)
         fip_ns_name = router1.fip_ns.get_name()
         self.assertTrue(self._namespace_exists(router1.ns_name))
@@ -1600,7 +1706,7 @@ class TestDvrRouter(framework.L3AgentTestFramework):
         # Now remove the gateway and validate if the respective interface
         # routes in router namespace is deleted respectively.
         self. _assert_interface_rules_on_gateway_remove(
-            router1, self.agent, address_scopes, fip_agent_gw_port[0],
+            router1, self.agent, address_scopes, fip_agent_gw_ports[0],
             rfp_device, fpr_device)
 
     def test_dvr_fip_and_router_namespace_rules_with_address_scopes_match(
@@ -1611,6 +1717,56 @@ class TestDvrRouter(framework.L3AgentTestFramework):
         self):
         self._setup_dvr_router_for_fast_path_exit(address_scopes=False)
 
+    @mock.patch.object(dvr_local_router.DvrLocalRouter,
+                       '_add_interface_routing_rule_to_router_ns')
+    @mock.patch.object(dvr_local_router.DvrLocalRouter,
+                       '_add_interface_route_to_fip_ns')
+    def test_dvr_no_external_router_namespace_rules_with_address_scopes_match(
+        self, mock_add_interface_route_rule,
+        mock_add_fip_interface_route_rule):
+        """Test to validate the router namespace routes.
+
+        This test validates the router namespace routes
+        that are based on the address scopes.
+        If the address scopes of internal network and external network
+        matches, the traffic will be forwarded to SNAT namespace
+        for agents that don't have external connectivity or configured
+        as DVR_NO_EXTERNAL.
+        """
+        self.agent.conf.agent_mode = (
+            n_const.L3_AGENT_MODE_DVR_NO_EXTERNAL)
+        router_info = self.generate_dvr_router_info(
+            enable_snat=True, enable_gw=True, enable_floating_ip=True)
+        router_info[lib_constants.FLOATINGIP_KEY] = []
+        address_scope1 = {
+            str(lib_constants.IP_VERSION_4): 'scope1'}
+        address_scope2 = {
+            str(lib_constants.IP_VERSION_4): 'scope1'}
+        router_info['gw_port']['address_scopes'] = {
+            str(lib_constants.IP_VERSION_4): 'scope1'}
+        router_info[lib_constants.INTERFACE_KEY][0]['address_scopes'] = (
+            address_scope1)
+        router_info[lib_constants.INTERFACE_KEY][1]['address_scopes'] = (
+            address_scope2)
+        router1 = self.manage_router(self.agent, router_info)
+        self.assertTrue(self._namespace_exists(router1.ns_name))
+        self.assertFalse(mock_add_interface_route_rule.called)
+        self.assertFalse(mock_add_fip_interface_route_rule.called)
+        # Check if any snat redirect rules in the router namespace exist.
+        ns_ipr = ip_lib.IPRule(namespace=router1.ns_name)
+        ip4_rules_list = ns_ipr.rule.list_rules(lib_constants.IP_VERSION_4)
+        ip6_rules_list = ns_ipr.rule.list_rules(lib_constants.IP_VERSION_6)
+        # Just make sure the basic set of rules are there in the router
+        # namespace
+        self.assertEqual(5, len(ip4_rules_list))
+        self.assertEqual(2, len(ip6_rules_list))
+
+        # Now remove the gateway and validate if the respective interface
+        # routes in router namespace is deleted respectively.
+        self. _assert_interface_rules_on_gateway_remove(
+            router1, self.agent, True, mock.ANY,
+            mock.ANY, mock.ANY, True)
+
     def test_dvr_router_gateway_update_to_none(self):
         self.agent.conf.agent_mode = 'dvr_snat'
         router_info = self.generate_dvr_router_info(enable_snat=True)
@@ -1668,6 +1824,10 @@ class TestDvrRouter(framework.L3AgentTestFramework):
         if gw_address_scope:
             router_info['gw_port']['address_scopes'] = {
                 str(lib_constants.IP_VERSION_4): gw_address_scope}
+            fip_agent_gw_ports = router_info[
+                n_const.FLOATINGIP_AGENT_INTF_KEY]
+            fip_agent_gw_ports[0]['address_scopes'] = router_info['gw_port'][
+                'address_scopes']
         router_info[lib_constants.INTERFACE_KEY][0]['address_scopes'] = (
             address_scope1)
         router_info[lib_constants.INTERFACE_KEY][1]['address_scopes'] = (
