@@ -111,6 +111,8 @@ class BaseFirewallTestCase(base.BaseSudoTestCase):
         # FIXME(jlibosva): We should consider to call prepare_port_filter with
         # deferred bridge depending on its performance
         self.firewall.prepare_port_filter(self.src_port_desc)
+        # Traffic coming from patch-port is always VLAN tagged
+        self.tester.set_peer_port_as_patch_port()
 
     def initialize_iptables(self):
         cfg.CONF.set_override('enable_ipset', self.enable_ipset,
@@ -277,7 +279,7 @@ class FirewallTestCase(BaseFirewallTestCase):
                                (outgoing_rule_pref, i['port_range_min']))
                    for i in sg_rules]
         # all indexes should be in order with no unexpected rules in between
-        self.assertEqual(range(indexes[0], indexes[-1] + 1), indexes)
+        self.assertEqual(list(range(indexes[0], indexes[-1] + 1)), indexes)
 
     def test_ingress_icmp_secgroup(self):
         # update the sg_group to make ping pass
@@ -573,6 +575,8 @@ class FirewallTestCase(BaseFirewallTestCase):
         self.assertEqual(packets_received, 0)
 
     def test_remote_security_groups(self):
+        self.tester.set_peer_port_as_vm_port()
+
         remote_sg_id = 'remote_sg_id'
         peer_port_desc = self._create_port_description(
             self.tester.peer_port_id,
