@@ -13,10 +13,11 @@
 #    under the License.
 
 import collections
+from contextlib import contextmanager
+import subprocess
 
 from alembic.ddl import base as alembic_ddl
 from alembic import script as alembic_script
-from contextlib import contextmanager
 from oslo_config import cfg
 from oslo_config import fixture as config_fixture
 from oslo_db.sqlalchemy import test_migrations
@@ -25,8 +26,8 @@ import six
 import sqlalchemy
 from sqlalchemy import event  # noqa
 from sqlalchemy.sql import ddl as sqla_ddl
-import subprocess
 
+from neutron.db import migration as migration_root
 from neutron.db.migration.alembic_migrations import external
 from neutron.db.migration import cli as migration
 from neutron.db.migration.models import head as head_models
@@ -290,10 +291,19 @@ class _TestModelsMigrations(test_migrations.ModelsMigrationsSync):
         find_migration_exceptions()
         engine = self.engine
         cfg.CONF.set_override('connection', engine.url, group='database')
+
         with engine.begin() as connection:
             self.alembic_config.attributes['connection'] = connection
-            migration.do_alembic_command(self.alembic_config, 'upgrade',
-                                         'kilo')
+
+            # upgrade to latest release first; --expand users are expected to
+            # apply all alembic scripts from previous releases before applying
+            # the new ones
+            for release in migration_root.NEUTRON_MILESTONES:
+                release_revisions = migration._find_milestone_revisions(
+                    self.alembic_config, release)
+                for rev in release_revisions:
+                    migration.do_alembic_command(
+                        self.alembic_config, 'upgrade', rev[0])
 
             with self._listener(engine, check_expand_branch):
                 migration.do_alembic_command(
@@ -554,7 +564,18 @@ class _TestWalkMigrations(object):
 class TestWalkMigrationsMysql(testlib_api.MySQLTestCaseMixin,
                               _TestWalkMigrations,
                               testlib_api.SqlTestCaseLight):
-    pass
+
+    # NOTE(slaweq): this workaround is taken from Manila patch:
+    # https://review.openstack.org/#/c/291397/
+    # Set 5 minutes timeout for case of running it on
+    # very slow nodes/VMs. Note, that this test becomes slower with each
+    # addition of new DB migration. On fast nodes it can take about 5-10
+    # secs having Mitaka set of migrations. 'pymysql' works much slower
+    # on slow nodes than 'psycopg2' and because of that this increased
+    # timeout is required only when for testing with 'mysql' backend.
+    @test_base.set_timeout(600)
+    def test_walk_versions(self):
+        super(TestWalkMigrationsMysql, self).test_walk_versions()
 
 
 class TestWalkMigrationsPsql(testlib_api.PostgreSQLTestCaseMixin,
