@@ -13,39 +13,63 @@
 #    under the License.
 
 import mock
+from neutron_lib import constants as n_const
 import testtools
 import webob
 
+from oslo_config import cfg
+from oslo_config import fixture as config_fixture
+from oslo_utils import fileutils
+
 from neutron.agent.linux import utils as agent_utils
 from neutron.agent.metadata import agent
-from neutron.agent.metadata import config
 from neutron.agent import metadata_agent
-from neutron.common import constants as n_const
+from neutron.common import cache_utils as cache
 from neutron.common import utils
+from neutron.conf.agent.metadata import config as meta_conf
 from neutron.tests import base
 
 
-class FakeConf(object):
-    auth_ca_cert = None
-    nova_metadata_ip = '9.9.9.9'
-    nova_metadata_port = 8775
-    metadata_proxy_shared_secret = 'secret'
-    nova_metadata_protocol = 'http'
-    nova_metadata_insecure = True
-    nova_client_cert = 'nova_cert'
-    nova_client_priv_key = 'nova_priv_key'
-    cache_url = ''
+class ConfFixture(config_fixture.Config):
+    def setUp(self):
+        super(ConfFixture, self).setUp()
+        meta_conf.register_meta_conf_opts(
+            meta_conf.METADATA_PROXY_HANDLER_OPTS, self.conf)
+        self.config(auth_ca_cert=None,
+                    nova_metadata_host='9.9.9.9',
+                    nova_metadata_port=8775,
+                    metadata_proxy_shared_secret='secret',
+                    nova_metadata_protocol='http',
+                    nova_metadata_insecure=True,
+                    nova_client_cert='nova_cert',
+                    nova_client_priv_key='nova_priv_key')
+        cache.register_oslo_configs(self.conf)
+        self.config(cache_url='')
 
 
-class FakeConfCache(FakeConf):
-    cache_url = 'memory://?default_ttl=5'
+class CacheConfFixture(ConfFixture):
+    def setUp(self):
+        super(CacheConfFixture, self).setUp()
+        self.config(cache_url='memory://?default_ttl=5')
+
+
+class NewCacheConfFixture(ConfFixture):
+    def setUp(self):
+        super(NewCacheConfFixture, self).setUp()
+        self.config(
+            group='cache',
+            enabled=True,
+            backend='oslo_cache.dict',
+            expiration_time=5)
 
 
 class TestMetadataProxyHandlerBase(base.BaseTestCase):
-    fake_conf = FakeConf
+    fake_conf = cfg.CONF
+    fake_conf_fixture = ConfFixture(fake_conf)
 
     def setUp(self):
         super(TestMetadataProxyHandlerBase, self).setUp()
+        self.useFixture(self.fake_conf_fixture)
         self.log_p = mock.patch.object(agent, 'LOG')
         self.log = self.log_p.start()
         self.handler = agent.MetadataProxyHandler(self.fake_conf)
@@ -84,8 +108,7 @@ class TestMetadataProxyHandlerRpc(TestMetadataProxyHandlerBase):
         self.assertEqual(expected, ports)
 
 
-class TestMetadataProxyHandlerCache(TestMetadataProxyHandlerBase):
-    fake_conf = FakeConfCache
+class _TestMetadataProxyHandlerCacheMixin(object):
 
     def test_call(self):
         req = mock.Mock()
@@ -337,10 +360,10 @@ class TestMetadataProxyHandlerCache(TestMetadataProxyHandlerBase):
                     ca_certs=None, disable_ssl_certificate_validation=True)
                 mock_http.assert_has_calls([
                     mock.call().add_certificate(
-                        FakeConf.nova_client_priv_key,
-                        FakeConf.nova_client_cert,
-                        "%s:%s" % (FakeConf.nova_metadata_ip,
-                                   FakeConf.nova_metadata_port)
+                        self.fake_conf.nova_client_priv_key,
+                        self.fake_conf.nova_client_cert,
+                        "%s:%s" % (self.fake_conf.nova_metadata_host,
+                                   self.fake_conf.nova_metadata_port)
                     ),
                     mock.call().request(
                         'http://9.9.9.9:8775/the_path',
@@ -398,8 +421,21 @@ class TestMetadataProxyHandlerCache(TestMetadataProxyHandlerBase):
         )
 
 
+class TestMetadataProxyHandlerCache(TestMetadataProxyHandlerBase,
+                                    _TestMetadataProxyHandlerCacheMixin):
+    fake_conf = cfg.CONF
+    fake_conf_fixture = CacheConfFixture(fake_conf)
+
+
+class TestMetadataProxyHandlerNewCache(TestMetadataProxyHandlerBase,
+                                       _TestMetadataProxyHandlerCacheMixin):
+    fake_conf = cfg.CONF
+    fake_conf_fixture = NewCacheConfFixture(fake_conf)
+
+
 class TestMetadataProxyHandlerNoCache(TestMetadataProxyHandlerCache):
-    fake_conf = FakeConf
+    fake_conf = cfg.CONF
+    fake_conf_fixture = ConfFixture(fake_conf)
 
     def test_get_router_networks_twice(self):
         self._test_get_router_networks_twice_helper()
@@ -423,12 +459,12 @@ class TestUnixDomainMetadataProxy(base.BaseTestCase):
         self.cfg.CONF.metadata_proxy_socket = '/the/path'
         self.cfg.CONF.metadata_workers = 0
         self.cfg.CONF.metadata_backlog = 128
-        self.cfg.CONF.metadata_proxy_socket_mode = config.USER_MODE
+        self.cfg.CONF.metadata_proxy_socket_mode = meta_conf.USER_MODE
 
-    @mock.patch.object(utils, 'ensure_dir')
+    @mock.patch.object(fileutils, 'ensure_tree')
     def test_init_doesnot_exists(self, ensure_dir):
         agent.UnixDomainMetadataProxy(mock.Mock())
-        ensure_dir.assert_called_once_with('/the')
+        ensure_dir.assert_called_once_with('/the', mode=0o755)
 
     def test_init_exists(self):
         with mock.patch('os.path.isdir') as isdir:
@@ -462,12 +498,12 @@ class TestUnixDomainMetadataProxy(base.BaseTestCase):
 
     @mock.patch.object(agent, 'MetadataProxyHandler')
     @mock.patch.object(agent_utils, 'UnixDomainWSGIServer')
-    @mock.patch.object(utils, 'ensure_dir')
+    @mock.patch.object(fileutils, 'ensure_tree')
     def test_run(self, ensure_dir, server, handler):
         p = agent.UnixDomainMetadataProxy(self.cfg.CONF)
         p.run()
 
-        ensure_dir.assert_called_once_with('/the')
+        ensure_dir.assert_called_once_with('/the', mode=0o755)
         server.assert_has_calls([
             mock.call('neutron-metadata-agent'),
             mock.call().start(handler.return_value,
