@@ -13,6 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import datetime
+
 import mock
 
 from neutron_lib.api.definitions import port as port_def
@@ -55,6 +57,7 @@ TEST_ROUTER_ID = 'router_id'
 
 NOTIFIER = 'neutron.plugins.ml2.rpc.AgentNotifierApi'
 DEVICE_OWNER_COMPUTE = constants.DEVICE_OWNER_COMPUTE_PREFIX + 'fake'
+DEVICE_OWNER_ROUTER_HA_INTF = constants.DEVICE_OWNER_ROUTER_HA_INTF + 'fake'
 
 
 class FakeL3PluginWithAgents(common_db_mixin.CommonDbMixin,
@@ -352,6 +355,37 @@ class TestL2PopulationRpcTestCase(test_plugin.Ml2PluginV2TestCase):
                 self.mock_fanout.assert_called_with(
                     mock.ANY, 'remove_fdb_entries', expected)
 
+    def test_ovs_agent_restarted_with_dvr_port(self):
+        plugin = directory.get_plugin()
+        router = self._create_dvr_router()
+        with mock.patch.object(l2pop_mech_driver.L2populationMechanismDriver,
+                               'agent_restarted', return_value=True):
+            with self.subnet(network=self._network,
+                             enable_dhcp=False) as snet:
+                with self.port(
+                        subnet=snet,
+                        device_owner=constants.DEVICE_OWNER_DVR_INTERFACE)\
+                            as port:
+                    port_id = port['port']['id']
+                    plugin.update_distributed_port_binding(self.adminContext,
+                        port_id, {'port': {portbindings.HOST_ID: HOST_4,
+                        'device_id': router['id']}})
+                    port = self._show('ports', port_id)
+                    self.assertEqual(portbindings.VIF_TYPE_DISTRIBUTED,
+                                    port['port'][portbindings.VIF_TYPE])
+                    self.callbacks.update_device_up(self.adminContext,
+                                                agent_id=HOST_4,
+                                                device=port_id,
+                                                host=HOST_4)
+                    fanout_expected = {port['port']['network_id']: {
+                        'network_type': u'vxlan',
+                        'ports': {
+                            u'20.0.0.4': [('00:00:00:00:00:00', '0.0.0.0')]},
+                        'segment_id': 1}}
+                    self.mock_fanout.assert_called_with(mock.ANY,
+                                                        'add_fdb_entries',
+                                                        fanout_expected)
+
     def test_ha_agents_with_dvr_rtr_does_not_get_other_fdb(self):
         router = self._create_dvr_router()
         directory.add_plugin(plugin_constants.L3, self.plugin)
@@ -743,6 +777,60 @@ class TestL2PopulationRpcTestCase(test_plugin.Ml2PluginV2TestCase):
                 self.mock_fanout.assert_called_with(
                     mock.ANY, 'add_fdb_entries', expected)
 
+    def test_update_port_up_two_active_ports(self):
+        '''The test will check that even with 2 active ports on the host,
+        agent will be provided with the whole list of fdb entries. Bug 1789846
+        '''
+        self._register_ml2_agents()
+
+        with self.subnet(network=self._network) as subnet:
+            host_arg = {portbindings.HOST_ID: HOST}
+            # 2 ports on host 1
+            with self.port(subnet=subnet,
+                           device_owner=DEVICE_OWNER_COMPUTE,
+                           arg_list=(portbindings.HOST_ID,),
+                           **host_arg) as port1:
+                with self.port(subnet=subnet,
+                               device_owner=DEVICE_OWNER_COMPUTE,
+                               arg_list=(portbindings.HOST_ID,),
+                               **host_arg) as port2:
+                    # 1 port on another host to have fdb entree to update
+                    # agent on host 1
+                    host_arg = {portbindings.HOST_ID: HOST + '_2'}
+                    with self.port(subnet=subnet,
+                                   device_owner=DEVICE_OWNER_COMPUTE,
+                                   arg_list=(portbindings.HOST_ID,),
+                                   **host_arg) as port3:
+                        p1 = port1['port']
+                        p2 = port2['port']
+                        p3 = port3['port']
+
+                        # only ACTIVE ports count
+                        plugin = directory.get_plugin()
+                        p2['status'] = 'ACTIVE'
+                        plugin.update_port(self.adminContext, p2['id'], port2)
+                        p3['status'] = 'ACTIVE'
+                        plugin.update_port(self.adminContext, p3['id'], port3)
+
+                        self.mock_cast.reset_mock()
+                        p1['status'] = 'ACTIVE'
+                        plugin.update_port(self.adminContext, p1['id'], port1)
+
+                        # agent on host 1 should be updated with entry from
+                        # another host
+                        expected = {p3['network_id']:
+                            {'ports':
+                             {'20.0.0.2': [
+                                 constants.FLOODING_ENTRY,
+                                 l2pop_rpc.PortInfo(
+                                     p3['mac_address'],
+                                     p3['fixed_ips'][0]['ip_address'])]},
+                             'network_type': 'vxlan',
+                             'segment_id': 1}}
+
+                        self.mock_cast.assert_called_once_with(
+                            mock.ANY, 'add_fdb_entries', expected, HOST)
+
     def test_update_port_down(self):
         self._register_ml2_agents()
 
@@ -825,6 +913,45 @@ class TestL2PopulationRpcTestCase(test_plugin.Ml2PluginV2TestCase):
                     self.mock_fanout.assert_called_with(
                         mock.ANY, 'remove_fdb_entries', expected)
 
+    def test_update_port_down_ha_router_port(self):
+        router = self._create_ha_router()
+        directory.add_plugin(plugin_constants.L3, self.plugin)
+        with self.subnet(network=self._network, enable_dhcp=False) as snet:
+            subnet = snet['subnet']
+            router_port = self._add_router_interface(subnet, router, HOST)
+            router_port_device = 'tap' + router_port['id']
+
+            host_arg = {portbindings.HOST_ID: HOST_4, 'admin_state_up': True}
+            with self.port(subnet=snet,
+                           device_owner=DEVICE_OWNER_COMPUTE,
+                           arg_list=(portbindings.HOST_ID,),
+                           **host_arg) as port1:
+                p1 = port1['port']
+                device1 = 'tap' + p1['id']
+
+                self.callbacks.update_device_up(self.adminContext,
+                                                agent_id=HOST,
+                                                device=device1)
+                self.mock_fanout.reset_mock()
+                self.callbacks.update_device_down(self.adminContext,
+                                                  agent_id=HOST,
+                                                  device=router_port_device,
+                                                  host=HOST)
+
+                router_port_ips = [
+                    p['ip_address'] for p in router_port['fixed_ips']]
+                expected = {
+                    router_port['network_id']: {
+                        'ports': {
+                            '20.0.0.1': [
+                                l2pop_rpc.PortInfo(router_port['mac_address'],
+                                                   router_port_ips[0])]},
+                        'network_type': 'vxlan',
+                        'segment_id': 1}}
+
+                self.mock_fanout.assert_called_with(
+                    mock.ANY, 'remove_fdb_entries', expected)
+
     def test_delete_port(self):
         self._register_ml2_agents()
 
@@ -1360,3 +1487,25 @@ class TestL2PopulationMechDriver(base.BaseTestCase):
         mech_driver = l2pop_mech_driver.L2populationMechanismDriver()
         with testtools.ExpectedException(exceptions.InvalidInput):
             mech_driver.update_port_precommit(ctx)
+
+    def test_agent_restarted(self):
+        mech_driver = l2pop_mech_driver.L2populationMechanismDriver()
+        ctx = mock.Mock()
+        ctx.host = "__host1__"
+        ctx._plugin_context = {}
+        agent = mock.Mock()
+        agent.started_at = datetime.datetime(2018, 5, 25, 15, 51, 20)
+        agent.heartbeat_timestamp = datetime.datetime(2018, 5, 25, 15,
+                                                      51, 50)
+
+        with mock.patch.object(l2pop_db, 'get_agent_by_host',
+                               return_value=agent):
+            res = mech_driver.agent_restarted(ctx)
+            self.assertTrue(res)
+
+        agent.heartbeat_timestamp = datetime.datetime(2018, 5, 25, 15,
+                                                      58, 30)
+        with mock.patch.object(l2pop_db, 'get_agent_by_host',
+                               return_value=agent):
+            res = mech_driver.agent_restarted(ctx)
+            self.assertFalse(res)
