@@ -16,6 +16,7 @@
 
 import mock
 
+from neutron.agent.linux import ip_link_support
 from neutron.plugins.ml2.drivers.mech_sriov.agent.common \
     import exceptions as exc
 from neutron.plugins.ml2.drivers.mech_sriov.agent import pci_lib
@@ -127,22 +128,42 @@ class TestPciLib(base.BaseTestCase):
                               self.VF_INDEX,
                               True)
 
-    def test_set_vf_max_rate(self):
-        with mock.patch.object(self.pci_wrapper, "_as_root") \
-                as mock_as_root:
-            result = self.pci_wrapper.set_vf_max_rate(self.VF_INDEX, 1000)
-            self.assertIsNone(result)
-        mock_as_root.assert_called_once_with([], "link",
-            ("set", self.DEV_NAME, "vf", str(self.VF_INDEX), "rate", '1000'))
+    def _set_vf_rate(self, rate, passed=True):
+        if passed:
+            with mock.patch.object(self.pci_wrapper, "_as_root") \
+                    as mock_as_root:
+                result = self.pci_wrapper.set_vf_rate(
+                    self.VF_INDEX,
+                    ip_link_support.IpLinkConstants.IP_LINK_CAPABILITY_RATE,
+                    1000)
+                self.assertIsNone(result)
+                mock_as_root.assert_called_once_with(
+                    [], "link", ("set", self.DEV_NAME, "vf",
+                                 str(self.VF_INDEX), "rate", '1000'))
+        else:
+            with mock.patch.object(self.pci_wrapper, "_execute",
+                                   side_effect=Exception()):
+                self.assertRaises(exc.IpCommandDeviceError,
+                                  self.pci_wrapper.set_vf_rate,
+                                  self.VF_INDEX,
+                                  rate,
+                                  1000)
 
-    def test_set_vf_max_rate_fail(self):
-        with mock.patch.object(self.pci_wrapper,
-                               "_execute") as mock_exec:
-            mock_exec.side_effect = Exception()
-            self.assertRaises(exc.IpCommandDeviceError,
-                              self.pci_wrapper.set_vf_max_rate,
-                              self.VF_INDEX,
-                              1000)
+    def test_set_vf_rate_max_rate(self):
+        self._set_vf_rate(
+            ip_link_support.IpLinkConstants.IP_LINK_CAPABILITY_RATE)
+
+    def test_set_vf_rate_max_rate_fail(self):
+        self._set_vf_rate('rate', passed=False)
+
+    def test_set_vf_rate_min_tx_rate(self):
+        self._set_vf_rate(
+            ip_link_support.IpLinkConstants.IP_LINK_CAPABILITY_MIN_TX_RATE)
+
+    def test_set_vf_rate_min_tx_rate_fail(self):
+        self._set_vf_rate(
+            ip_link_support.IpLinkConstants.IP_LINK_CAPABILITY_MIN_TX_RATE,
+            passed=False)
 
     def test_set_vf_state_not_supported(self):
         with mock.patch.object(self.pci_wrapper,
