@@ -13,14 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from neutron_lib import context
 from neutron_lib import exceptions as exc
+from neutron_lib.plugins.ml2 import api
 
 from neutron.common import exceptions as n_exc
-from neutron import context
 from neutron.objects.plugins.ml2 import flatallocation as flat_obj
 from neutron.plugins.common import constants as p_const
 from neutron.plugins.ml2 import config
-from neutron.plugins.ml2 import driver_api as api
 from neutron.plugins.ml2.drivers import type_flat
 from neutron.tests import base
 from neutron.tests.unit import testlib_api
