@@ -31,6 +31,7 @@ from sqlalchemy.orm import exc
 from neutron.agent import rpc as agent_rpc
 from neutron.common import topics
 from neutron.db import provisioning_blocks
+from neutron.plugins.ml2 import db as ml2_db
 from neutron.plugins.ml2.drivers import type_tunnel
 from neutron.plugins.ml2 import managers
 from neutron.plugins.ml2 import rpc as plugin_rpc
@@ -222,11 +223,12 @@ class RpcCallbacksTestCase(base.BaseTestCase):
         return res
 
     def test_update_device_up_with_device_not_bound_to_host(self):
-        self.assertIsNone(self._test_update_device_not_bound_to_host(
-            self.callbacks.update_device_up))
-        port = self.plugin._get_port.return_value
-        (self.plugin.nova_notifier.notify_port_active_direct.
-         assert_called_once_with(port))
+        with mock.patch.object(ml2_db, 'get_port') as ml2_db_get_port:
+            self.assertIsNone(self._test_update_device_not_bound_to_host(
+                self.callbacks.update_device_up))
+            port = ml2_db_get_port.return_value
+            (self.plugin.nova_notifier.notify_port_active_direct.
+             assert_called_once_with(port))
 
     def test_update_device_down_with_device_not_bound_to_host(self):
         self.assertEqual(
